## [0.1.2] - 2024-12-10
### Added
### Changed
* `api.cross_corr` now only reports possible memory issues when `verbose=True`

### Deprecated
### Removed
### Fixed
### Security


## [0.1.1] - 2024-12-01
### Added
* Additional documentation for FF-PIV API
* New examples in the FF-PIV package

### Changed
* Improved performance of FF-PIV when processing large datasets

### Deprecated
### Removed
### Fixed
* Bug fixes for data processing errors

### Security

## [0.1.0] - 2024-11-14
### Added
* First release of FF-PIV

### Changed
### Deprecated
### Removed
### Fixed
### Security
